@@ -7,7 +7,9 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.050';
+our $VERSION = '0.069';
+
+use constant ARRAY_REF	=> ref [];
 
 sub new {
     my ( $class, %arg ) = @_;
@@ -16,7 +18,7 @@ sub new {
 
 sub capture {
     my ( $self ) = @_;
-    'ARRAY' eq ref $self->{capture}
+    ARRAY_REF eq ref $self->{capture}
 	or return;
     return @{ $self->{capture} };
 }
@@ -55,8 +57,8 @@ This Perl class is private to the C<PPIx-Regexp> package, and may be
 modified or retracted without notice. Documentation is for the benefit
 of the author.
 
-represents a mock tokenizer to be used in testing. It implements those
-methods that the author finds useful.
+It represents a mock tokenizer to be used in testing. It implements
+those methods that the author finds useful.
 
 =head1 METHODS
 
@@ -107,7 +109,7 @@ L<PPIx::Regexp::Tokenizer|PPIx::Regexp::Tokenizer>
 
 This module is private to the C<PPIx-Regexp> package. It is unsupported
 in the sense that the author reserves the right to modify or retract it
-without prior appeoval. Bug reports filed via L<http://rt.cpan.org>, or
+without prior appeoval. Bug reports filed via L<https://rt.cpan.org>, or
 in electronic mail to the author will be accepted if they document a
 problem with this module that results in spurious test results.
 
@@ -117,7 +119,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015-2016 by Thomas R. Wyant, III
+Copyright (C) 2015-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
