@@ -56,12 +56,12 @@ for little tangible gain.
 =head1 NOTICE
 
 The use of this class to parse non-regexp quote-like strings was an
-experiment that I consider failed. Therefore this use is
-B<deprecated> in favor of L<PPIx::QuoteLike|PPIx::QuoteLike>. Six months
-after the release of version 0.053, the first use of the C<parse>
-argument to L<new()|/new> will result in a warning. Six months after
-that, all uses of the C<parse> argument will result in a warning. After
-another six months, the C<parse> argument will become fatal.
+experiment that I consider failed. Therefore this use is B<deprecated>
+in favor of L<PPIx::QuoteLike|PPIx::QuoteLike>. As of version 0.058_01,
+the first use of the C<parse> argument to L<new()|/new> resulted in a
+warning. As of version 0.062_01, all uses of the C<parse> argument
+resulted in a warning. As of version 0.068_01, the C<parse> argument
+will become fatal.
 
 The author will attempt to preserve the documented interface, but if the
 interface needs to change to correct some egregiously bad design or
@@ -120,19 +120,27 @@ These are being removed in positions where quantifiers are legal, so
 that they can be used for new functionality. Some of them are gone in
 5.25.1, others will be removed in a future version of Perl. In
 situations where they have been removed,
-L<perl_version_removed()|/perl_version_removed> will return the version
-in which they were removed. When the new functionality appears, the
-parse produced by this software will reflect the new functionality.
+L<perl_version_removed()|PPIx::Regexp::Element/perl_version_removed>
+will return the version in which they were removed. When the new
+functionality appears, the parse produced by this software will reflect
+the new functionality.
 
-B<NOTE> that a literal left curly after a literal character was made an
-error in Perl 5.25.1, but became a warning again in 5.27.1 due to its
-use in GNU Autoconf.  Whether it will ever become illegal again is not
-clear to me based on the contents of F<perl5271delta>. At the moment
-C<PPIx::Regexp> considers this usage to have been removed in 5.25.1, and
-this will not change based on anything in 5.27.x. But if 5.26.1 comes
-out allowing this usage, the removal version will become C<undef>. The
-same will apply to any other usages that were re-allowed in 5.27.1, if I
-can identify them.
+B<NOTE> that the situation with a literal left curly after a literal
+character is complicated. It was made an error in Perl 5.25.1, and
+remained so through all 5.26 releases, but became a warning again in
+5.27.1 due to its use in GNU Autoconf. Whether it will ever become
+illegal again is not clear to me based on the contents of
+F<perl5271delta>. At the moment
+L<perl_version_removed()|PPIx::Regexp::Element/perl_version_removed>
+returns C<undef>, but obviously that is not the whole story, and methods
+L<accepts_perl()|PPIx::Regexp::Element/accepts_perl> and
+L<requirements_for_perl()|PPIx::Regexp::Element/requirements_for_perl>
+were introduced to deal with this complication.
+
+=item C<\o{...}>
+
+is parsed as the octal equivalent of C<\x{...}>. This is its meaning as
+of perl 5.13.2. Before 5.13.2 it was simply literal C<'o'> and so on.
 
 =back
 
@@ -140,13 +148,6 @@ There are very probably other examples of this. When they come to light
 they will be documented as producing the modern parse, and the code
 modified to produce this parse if necessary.
 
-The functionality that parses string literals (the C<parse> argument to
-C<new()>) was introduced in version 0.045, but its use is discouraged.
-The preferred package for string literals is
-L<PPIx::QuoteLike|PPIx::QuoteLike>, and once I consider that package to
-be stable the string literal functionality in this package will be put
-through a deprecation cycle and removed.
-
 =head1 METHODS
 
 This class provides the following public methods. Methods not documented
@@ -162,14 +163,14 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Node };
 
+use PPIx::Regexp::Constant qw{ @CARP_NOT };
 use PPIx::Regexp::Lexer ();
-use PPIx::Regexp::StringTokenizer;
 use PPIx::Regexp::Token::Modifier ();	# For its modifier manipulations.
 use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.055';
+our $VERSION = '0.069';
 
 =head2 new
 
@@ -234,35 +235,8 @@ experimental.
 As it turns out, I consider parsing non-regexp quote-like things with
 this class to be a failed experiment, and the relevant functionality is
 being deprecated and removed in favor of
-L<PPIx::QuoteLike|PPIx::QuoteLike>. See above for details.
-
-If C<'regex'> is specified, the first argument is expected to be a valid
-regex, and parsed as though it were.
-
-If C<'string'> is specified, the first argument is expected to be a
-valid string literal and parsed as such. The return is still a
-C<PPIx::Regexp> object, but the
-L<regular_expression()|/regular_expression> and L<modifier()|/modifier>
-methods return nothing, and the L<replacement()|/replacement> method
-returns the content of the string.
-
-If C<'guess'> is specified, this method will try to guess what the first
-argument is. If the first argument is a L<PPI::Element|PPI::Element>,
-the guess will reflect the PPI parse. But the guess can be wrong if the
-first argument is a string representing an unusually-delimited regex.
-For example, C<'guess'> will parse C<"foo"> as a string, but Perl will
-parse it as a regex if preceded by a regex binding operator (e.g. C<$x
-=~ "foo">), as shown by
-
- perl -MO=Deparse -e '$x =~ "foo"'
-
-which prints
-
- $x =~ /foo/u
-
-under Perl 5.22.0.
-
-The default is C<'regex'>.
+L<PPIx::QuoteLike|PPIx::QuoteLike>. See above for details. As of version
+0.068_01, any use of this option throws an exception.
 
 =item postderef boolean
 
@@ -326,13 +300,9 @@ is it supported.
 
 	$errstr = undef;
 
-	my $tokenizer_class = __choose_tokenizer_class( $content, \%args )
-	    or do {
-	    $errstr = ref $content ?
-		sprintf '%s not supported', ref $content :
-		"Unknown parse type '$args{parse}'";
-	    return;
-	};
+	# As of 0.068_01 this either fails or returns
+	# PPIx::Regexp::Tokenizer
+	my $tokenizer_class = __choose_tokenizer_class( $content, \%args );
 
 	my $tokenizer = $tokenizer_class->new(
 	    $content, %args ) or do {
@@ -522,6 +492,38 @@ sub explain {
     return;
 }
 
+=head2 extract_regexps
+
+ my $doc = PPI::Document->new( $path );
+ $doc->index_locations();
+ my @res = PPIx::Regexp->extract_regexps( $doc )
+
+This convenience (well, sort-of) static method takes as its argument a
+L<PPI::Document|PPI::Document> object and returns C<PPIx::Regexp>
+objects corresponding to all regular expressions found in it, in the
+order in which they occur in the document. You will need to keep a
+reference to the original L<PPI::Document|PPI::Document> object if you
+wish to be able to recover the original L<PPI::Element|PPI::Element>
+objects via the L<PPIx::Regexp|PPIx::Regexp>
+L<source()|PPIx::Regexp/source> method.
+
+=cut
+
+sub extract_regexps {
+    my ( $class, $doc ) = @_;
+    my @found = map { @{ $doc->find( $_ ) || [] } } qw{
+	PPI::Token::QuoteLike::Regexp
+	PPI::Token::Regexp::Match
+	PPI::Token::Regexp::Substitute
+    };
+    return ( map { $class->new( $_ ) } map { $_->[0] }
+	sort { $a->[1][0] <=> $b->[1][0] || $a->[1][1] <=> $b->[1][1] }
+	map { [ $_, $_->location() ] }
+	@found
+    );
+}
+
+
 =head2 failures
 
  print "There were ", $re->failures(), " parse failures\n";
@@ -736,7 +738,9 @@ then follow that interpolation by a character class.
 The F<perlop> documentation notes that in this case what Perl does is to
 guess. That is, it employs various heuristics on the code to try to
 figure out what the programmer wanted. These heuristics are documented
-as being undocumented (!) and subject to change without notice.
+as being undocumented (!) and subject to change without notice. As an
+example of the problems even F<perl> faces in parsing Perl, see
+L<https://github.com/perl/perl5/issues/16478>.
 
 Given this situation, this module's chances of duplicating every Perl
 version's interpretation of every regular expression are pretty much nil.
@@ -762,11 +766,12 @@ generally assumes the more modern parse in cases like this.
 
 Very occasionally, a construction will be removed and then added back --
 and then, conceivably, removed again. In this case, the plan is for
-L<perl_version_introduced()|PPIx::Regexp/perl_version_introduced> to
-return the earliest version in which the construction appeared, and
-L<perl_version_removed()> to return the version after the last version
-in which it appeared (whether production or development), or C<undef> if
-it is in the highest-numbered Perl.
+L<perl_version_introduced()|PPIx::Regexp::Element/perl_version_introduced>
+to return the earliest version in which the construction appeared, and
+L<perl_version_removed()|PPIx::Regexp::Element/perl_version_removed> to
+return the version after the last version in which it appeared (whether
+production or development), or C<undef> if it is in the highest-numbered
+Perl.
 
 The constructions involved in this are:
 
@@ -780,13 +785,15 @@ was re-instated because the changes broke GNU Autoconf, and the warning
 message says it will be removed in Perl C<5.30>.
 
 Accordingly,
-L<perl_version_introduced()|PPIx::Regexp/perl_version_introduced>
+L<perl_version_introduced()|PPIx::Regexp::Element/perl_version_introduced>
 returns C<5.0>. At the moment
-L<perl_version_removed()|PPIx::Regexp/perl_version_removed> returns
-C<'5.025001'>, but if this construction warns in Perl C<5.26.1> this
-will become C<undef>. This is not quite the same as described above, but
-is consistent with the L<NOTICE|/NOTICE> near the beginning of this
-document.
+L<perl_version_removed()|PPIx::Regexp::Element/perl_version_removed> returns
+C<'5.025001'>. But if it is present with or without warning in C<5.28>,
+L<perl_version_removed()|PPIx::Regexp::Element/perl_version_removed> will become
+C<undef>. If you need finer resolution than this, see
+L<PPIx::Regexp::Element|PPIx::Regexp::Element> methods
+l<accepts_perl()|PPIx::Regexp::Element/accepts_perl> and
+l<requirements_for_perl()|PPIx::Regexp::Element/requirements_for_perl>
 
 =head2 Static Parsing
 
@@ -838,8 +845,9 @@ following modules are known to cause problems:
 
 L<Acme::PerlML|Acme::PerlML>, which renders Perl as XML.
 
-L<Data::PostfixDeref|Data::PostfixDeref>, which causes Perl to interpret
-suffixed empty brackets as dereferencing the thing they suffix.
+C<Data::PostfixDeref>, which causes Perl to interpret suffixed empty
+brackets as dereferencing the thing they suffix. This module by Ben
+Morrow (C<BMORROW>) appears to have been retracted.
 
 L<Filter::Trigraph|Filter::Trigraph>, which recognizes ANSI C trigraphs,
 allowing Perl to be written in the ISO 646 character set.
@@ -854,14 +862,21 @@ in various ways, some of which seem to conflict with Perl 5.010.
 
 =head1 SEE ALSO
 
+L<Regexp::Parsertron|Regexp::Parsertron>, which uses
+L<Marpa::R2|Marpa::R2> to parse the regexp, and L<Tree|Tree> for
+navigation. Unlike C<PPIx::Regexp|PPIx::Regexp>,
+L<Regexp::Parsertron|Regexp::Parsertron> supports modification of the
+parse tree.
+
 L<Regexp::Parser|Regexp::Parser>, which parses a bare regular expression
 (without enclosing C<qr{}>, C<m//>, or whatever) and uses a different
-navigation model.
+navigation model. After a long hiatus, this module has been adopted, and
+is again supported.
 
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -869,7 +884,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
