@@ -8,12 +8,13 @@ use base qw{ Exporter };
 # CAVEAT: do not include any other PPIx-Regexp modules in this one, or
 # you will end up with a circular dependency.
 
-our $VERSION = '0.064';
+our $VERSION = '0.069';
 
 our @EXPORT_OK = qw{
     ARRAY_REF
     CODE_REF
     COOKIE_CLASS
+    COOKIE_LOOKAROUND_ASSERTION
     COOKIE_QUANT
     COOKIE_QUOTE
     COOKIE_REGEX_SET
@@ -47,7 +48,6 @@ our @CARP_NOT = qw{
     PPIx::Regexp::Node
     PPIx::Regexp::Node::Range
     PPIx::Regexp::Node::Unknown
-    PPIx::Regexp::StringTokenizer
     PPIx::Regexp::Structure
     PPIx::Regexp::Structure::Assertion
     PPIx::Regexp::Structure::Atomic_Script_Run
@@ -111,6 +111,7 @@ use constant COOKIE_CLASS	=> ']';
 use constant COOKIE_QUANT	=> '}';
 use constant COOKIE_QUOTE	=> '\\E';
 use constant COOKIE_REGEX_SET	=> '])';
+use constant COOKIE_LOOKAROUND_ASSERTION	=> 'lookaround';
 
 use constant FALSE		=> 0;
 use constant TRUE		=> 1;
@@ -214,6 +215,15 @@ L<PPIx::Regexp::Token::Structure|PPIx::Regexp::Token::Structure> when
 the left square bracket is encountered, and cleared in the same module
 when a right square bracket is encountered.
 
+=head2 COOKIE_LOOKAROUND_ASSERTION
+
+The name of the cookie used to control the parsing of zero-width
+assertions.
+
+This cookie is set in
+L<PPIx::Regexp::Token::GroupType::Assertion|PPIx::Regexp::Token::GroupType::Assertion>,
+and it persists until the end of the assertion.
+
 =head2 COOKIE_QUANT
 
 The name of the cookie used to control the construction of curly
@@ -333,7 +343,7 @@ L<PPIx::Regexp::Token::Unknown|PPIx::Regexp::Token::Unknown>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -341,7 +351,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2019 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
