@@ -41,10 +41,14 @@ use Carp;
 use Scalar::Util qw{ blessed looks_like_number };
 
 use PPIx::Regexp;
+use PPIx::Regexp::Constant qw{
+    ARRAY_REF
+    @CARP_NOT
+};
 use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 
-our $VERSION = '0.055';
+our $VERSION = '0.069';
 
 =head2 new
 
@@ -217,7 +221,7 @@ ignored.
 	    $self->{tokens} = 1;
 	} elsif ( __instance( $re, 'PPIx::Regexp::Element' ) ) {
 	    $self->{object} = $re;
-	} elsif ( ref $re eq 'ARRAY' ) {
+	} elsif ( ARRAY_REF eq ref $re ) {
 	    $self->{object} = $re;
 	} elsif ( ref $re && ! __instance( $re, 'PPI::Element' ) ) {
 	    croak "Do not know how to dump ", ref $re;
@@ -254,7 +258,7 @@ sub list {
     my ( $self ) = @_;
     my $lister = $self->{test} ? '__PPIX_DUMPER__test' : '__PPIX_DUMPER__dump';
 
-    ref $self->{object} eq 'ARRAY'
+    ARRAY_REF eq ref $self->{object}
 	and return ( map { $_->$lister( $self ) } @{ $self->{object} } );
 
     return $self->{object}->$lister( $self );
@@ -270,6 +274,13 @@ This method simply prints the result of L</string> to standard out.
 
 sub print : method {	## no critic (ProhibitBuiltinHomonyms)
     my ( $self ) = @_;
+    # Non-characters and Non-Unicode code points are explicitly allowed
+    # as delimiters, at least as of 5.29.0, which is where unassigned
+    # and combining code points became illegal. Unfortunately the
+    # warnings below were not introduced until 5.14, so have to go for
+    # the next-higher warning category.
+    # no warnings qw{ nonchar non_unicode };	## no critic (ProhibitNoWarnings)
+    no warnings qw{ utf8 };	## no critic (ProhibitNoWarnings)
     print $self->string();
     return;
 }
@@ -300,7 +311,7 @@ sub _safe {
 	}
 	if ( ! defined $item ) {
 	    push @rslt, 'undef';
-	} elsif ( ref $item eq 'ARRAY' ) {
+	} elsif ( ARRAY_REF eq ref $item ) {
 	    push @rslt, join( ' ', '[', $self->_safe( @{ $item } ), ']' );
 	} elsif ( looks_like_number( $item ) ) {
 	    push @rslt, $item;
@@ -323,7 +334,7 @@ sub __nav {
     my $rslt = $self->_safe( @args );
     $rslt =~ s/ ' (\w+) ' , /$1 =>/smxg;
     $rslt =~ s/ \[ \s+ \] /[]/smxg;
-    $rslt =~ s/ \[ \s* ( \d+ ) \s* \] /$1/smxg;
+    $rslt =~ s/ \[ \s* ( [0-9]+ ) \s* \] /$1/smxg;
     return $rslt;
 }
 
@@ -338,7 +349,7 @@ sub _content {
     defined $dflt or $dflt = '';
 
     defined $elem or return $dflt;
-    if ( ref $elem eq 'ARRAY' ) {
+    if ( ARRAY_REF eq ref $elem ) {
 	my $rslt = join '',
 	    map { $self->_content( $_ ) }
 	    grep { ! $self->{significant} || $_->significant() }
@@ -368,7 +379,7 @@ sub _format_default_modifiers {
     foreach my $attr ( qw{ default_modifiers parse postderef strict } ) {
 	defined ( my $val = $self->{$attr} )
 	    or next;
-	'ARRAY' eq ref $val
+	ARRAY_REF eq ref $val
 	    and not @{ $val }
 	    and next;
 	push @arg, "$attr => @{[ $self->_safe( $val ) ]}";
@@ -491,7 +502,7 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__test {
     my @rslt;
     @rslt = (
 	'choose  ( ' . $dumper->__nav( $self->nav() ) . ' );',
-	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
+	'klass   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'count   ( ' . scalar $self->children() . ' );',
     );
 
@@ -598,7 +609,7 @@ sub PPIx::Regexp::Structure::__PPIX_DUMPER__test {
     my @nav = $self->nav();
     my @rslt = (
 	'choose  ( ' . $dumper->__nav( @nav ) . ' );',
-	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
+	'klass   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'count   ( ' . scalar $self->children() . ' );',
     );
     if ( $dumper->{verbose} ) {
@@ -617,7 +628,7 @@ sub PPIx::Regexp::Structure::__PPIX_DUMPER__test {
 	    my $elem = $eles[$inx];
 	    push @rslt, 'choose  ( ' . $dumper->__nav(
 		@nav, $method, $inx ) . ' );',
-		'class   ( ' . $dumper->_safe( ref $elem || $elem ) . ' );',
+		'klass   ( ' . $dumper->_safe( ref $elem || $elem ) . ' );',
 		'content ( ' . $dumper->_safe( $elem ) . ' );';
 	}
     }
@@ -709,7 +720,7 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__test {
     @nav or @nav = $self->nav();
     my @rslt = (
 	'choose  ( ' . join(', ', $dumper->__nav( @nav ) ) . ' );',
-	'class   ( ' . $dumper->_safe( ref $self ) . ' );',
+	'klass   ( ' . $dumper->_safe( ref $self ) . ' );',
 	'content ( ' . $dumper->_safe( $self ) . ' );',
     );
 
@@ -758,7 +769,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -766,7 +777,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
