@@ -50,7 +50,7 @@ use PPIx::Regexp::Constant qw{
     @CARP_NOT
 };
 
-our $VERSION = '0.062';
+our $VERSION = '0.069';
 
 =head2 accepts_perl
 
@@ -197,6 +197,8 @@ will be put through a deprecation cycle and retracted.
 
 sub explain {
     my ( $self ) = @_;
+    defined $self->{explanation}
+	and return $self->{explanation};
     my $explanation = $self->__explanation();
     my $content = $self->content();
     if ( my $main = $self->main_structure() ) {
@@ -547,7 +549,7 @@ list context.
 
 This method was inspired by jb's question on Perl Monks about stripping
 comments and white space from a regular expression:
-L<http://www.perlmonks.org/?node_id=1207556>
+L<https://www.perlmonks.org/?node_id=1207556>
 
 This method was added in version 0.053_01
 
@@ -903,7 +905,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -911,7 +913,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
