@@ -19,7 +19,8 @@ C<PPIx::Regexp::Token::CharClass::Simple> has no descendants.
 
 This class represents one of the simple character classes that can occur
 anywhere in a regular expression. This includes not only the truly
-simple things like \w, but also Unicode properties.
+simple things like \w, but also Unicode properties, including properties
+with wildcard values.
 
 =head1 METHODS
 
@@ -39,10 +40,31 @@ use PPIx::Regexp::Constant qw{
     COOKIE_CLASS
     LITERAL_LEFT_CURLY_REMOVED_PHASE_1
     LITERAL_LEFT_CURLY_REMOVED_PHASE_2
-    MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
+    MINIMUM_PERL
+    TOKEN_LITERAL
+    TOKEN_UNKNOWN
+    @CARP_NOT
 };
 
-our $VERSION = '0.055';
+our $VERSION = '0.069';
+
+use constant UNICODE_PROPERTY_LITERAL_VALUE => qr/
+		\{ \s* \^? \w [\w:=\s-]* \} |
+		[CLMNPSZ]	# perluniprops for 5.26.1
+    /smx;
+use constant UNICODE_PROPERTY_LITERAL =>
+    qr/ \A \\ [Pp] (?:
+	@{[ UNICODE_PROPERTY_LITERAL_VALUE ]}
+    ) /smx;
+
+# CAVEAT: The following regular expression, despite its name, matches
+# ALL unicode property values. To actually match a wildcard property you
+# must first eliminate anything that matches UNICODE_PROPERTY_LITERAL.
+use constant UNICODE_PROPERTY_WILDCARD =>
+    qr/ \A \\ [Pp] \{ \s* [\w\s-]+ [:=] [^}]+ \} /smx;
+
+use constant UNICODE_PROPERTY =>
+    qr/ @{[ UNICODE_PROPERTY_LITERAL ]} | @{[ UNICODE_PROPERTY_WILDCARD ]} /smx;
 
 {
 
@@ -77,13 +99,23 @@ our $VERSION = '0.055';
 	my ( $self ) = @_;
 	if ( $self->content() =~ m/ \A \\ ( [Pp] ) ( [{] .* [}] | . ) \z /smx ) {
 	    my ( $kind, $prop ) = ( $1, $2 );
+
+	    my $literal = ( $prop =~
+		m/ \A @{[ UNICODE_PROPERTY_LITERAL_VALUE ]} \z /smx );
+
 	    if ( 1 < length $prop ) {
 		$prop =~ s/ \A [{] //smx;
 		$prop =~ s/ [}] \z //smx;
 	    }
-	    return sprintf
+
+	    $literal
+		and return sprintf
 		q<Match character %s Unicode or custom property '%s'>,
 		$kind_of_match{$kind}, $prop;
+
+	    return sprintf
+		q<Match character %s Unicode wildcard property '%s'>,
+		$kind_of_match{$kind}, $prop;
 	}
 	return $self->SUPER::explain();
     }
@@ -164,14 +196,15 @@ our $VERSION = '0.055';
 	if ( defined( my $minver = $introduced{$content} ) ) {
 	    return $minver;
 	}
-	if ( $content =~ m/ \A \\ [Pp] /smxg ) {
-	    # I must have read perl5113delta and thought this
-	    # represented the change they were talking about, but I sure
-	    # don't see it now. So, until things become clearer ...
-#	    $content =~ m/ \G .*? [\s=-] /smxgc
-#		and return '5.011003';
-	    return '5.006001';
-	}
+	# I must have read perl5113delta and thought this
+	# represented the change they were talking about, but I sure
+	# don't see it now. So, until things become clearer ...
+#	$content =~ m/ \G .*? [\s=-] /smxgc
+#	    and return '5.011003';
+	$content  =~ UNICODE_PROPERTY_LITERAL
+	    and return '5.006001';
+	$content =~ UNICODE_PROPERTY_WILDCARD
+	    and return '5.029009';
 	return MINIMUM_PERL;
     }
 
@@ -218,11 +251,7 @@ sub __PPIX_TOKENIZER__regexp {
     }
 
     if ( my $accept = $tokenizer->find_regexp(
-	    qr{ \A \\ (?:
-		[wWsSdDvVhHXRNC] |
-		[Pp] \{ \s* \^? [\w:=\s-]+ \} |
-		[Pp] [CLMNPSZ]	# perluniprops for 5.26.1
-	    ) }smx
+	    qr{ \A \\ [wWsSdDvVhHXRNC] }smx
 	) ) {
 	if ( $in_class ) {
 	    my $match = $tokenizer->match();
@@ -240,6 +269,18 @@ sub __PPIX_TOKENIZER__regexp {
 	return $accept;
     }
 
+    if ( my $accept = $tokenizer->find_regexp( UNICODE_PROPERTY ) ) {
+	return $accept;
+    }
+
+    if ( my $accept = $tokenizer->find_regexp( qr< \A \\ p [{] \s* [}] >smx )
+    ) {
+	return $tokenizer->make_token( $accept, TOKEN_UNKNOWN, {
+		error => 'Empty \\p{} is an error',
+	    },
+	);
+    }
+
     return;
 }
 
@@ -250,7 +291,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -258,7 +299,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
