@@ -35,62 +35,9 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.055';
+use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-{
-
-    my %explanation = (
-	'?'	=> q<Match one of the following '|'-delimited alternatives>,
-    );
-
-    sub __explanation {
-	return \%explanation;
-    }
-}
-
-sub perl_version_introduced {
-#   my ( $self ) = @_;
-    return '5.005';
-}
-
-# Return true if the token can be quantified, and false otherwise
-# sub can_be_quantified { return };
-
-=begin comment
-
-sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
-
-    # The optional escape is because any non-open-bracket character may
-    # appear as the regular expression delimiter.
-    if ( my $accept = $tokenizer->find_regexp(
-	    qr{ \A \\? \? \( }smx ) ) {
-
-	# Leave the left paren, since it belongs to the condition.
-	--$accept;
-
-	$tokenizer->expect( qw{
-	    PPIx::Regexp::Token::Condition
-	    } );
-
-	return $accept;
-
-    }
-
-    return;
-
-}
-
-=end comment
-
-=cut
-
-sub __defining_string {
-    return (
-	{ suffix => '(' },
-	'?',
-    );
-}
+our $VERSION = '0.069';
 
 sub __match_setup {
     my ( undef, $tokenizer ) = @_;	# Invocant unused
@@ -98,6 +45,18 @@ sub __match_setup {
     return;
 }
 
+__PACKAGE__->__setup_class(
+    {
+	'?'	=> {
+	    expl	=> q<Match one of the following '|'-delimited alternatives>,
+	    intro	=> '5.005',
+	},
+    },
+    {
+	suffix	=> '(',
+    },
+);
+
 
 1;
 
@@ -106,7 +65,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -114,7 +73,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
