@@ -34,9 +34,9 @@ use warnings;
 use base qw{ PPIx::Regexp::Token::Reference };
 
 use Carp qw{ confess };
-use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME };
+use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME @CARP_NOT };
 
-our $VERSION = '0.055';
+our $VERSION = '0.069';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -76,7 +76,7 @@ sub perl_version_introduced {
 # the string.
 sub __PPIX_TOKEN__recognize {
     return (
-	[ qr{ \A \( \? (?: ( [-+]? \d+ )) \) }smx, { is_named => 0 } ],
+	[ qr{ \A \( \? (?: ( [-+]? [0-9]+ )) \) }smx, { is_named => 0 } ],
 	[ qr{ \A \( \? (?: R) \) }smx,
 	    { is_named => 0, capture => '0' } ],
 	[ qr{ \A \( \?  (?: & | P> ) ( @{[ RE_CAPTURE_NAME ]} ) \) }smxo,
@@ -91,7 +91,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -99,7 +99,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
