@@ -43,6 +43,7 @@ use PPIx::Regexp::Constant qw{
     COOKIE_REGEX_SET
     MINIMUM_PERL
     TOKEN_LITERAL
+    @CARP_NOT
 };
 
 # Tokens we are responsible for making, under at least some
@@ -53,7 +54,7 @@ use PPIx::Regexp::Token::Backreference	();
 use PPIx::Regexp::Token::Backtrack	();
 use PPIx::Regexp::Token::Recursion	();
 
-our $VERSION = '0.055';
+our $VERSION = '0.069';
 
 # Return true if the token can be quantified, and false otherwise
 
@@ -189,6 +190,7 @@ sub is_quantifier {
 		'PPIx::Regexp::Token::GroupType::Subexpression',
 		'PPIx::Regexp::Token::GroupType::Switch',
 		'PPIx::Regexp::Token::GroupType::Script_Run',
+		'PPIx::Regexp::Token::GroupType::Atomic_Script_Run',
 	    );
 
 	    # Accept the parenthesis.
@@ -225,7 +227,7 @@ sub is_quantifier {
 
 		    # Of literals, we accept exactly one comma provided it
 		    # is not immediately after a '{'. We also accept
-		    # anything that matches '\d';
+		    # anything that matches '[0-9]';
 		    if ( $token->isa( TOKEN_LITERAL ) ) {
 			my $character = $token->content();
 			if ( $character eq ',' ) {
@@ -233,7 +235,7 @@ sub is_quantifier {
 			    return $tokenizer->prior_significant_token(
 				'content' ) ne '{';
 			}
-			return $character =~ m/ \A \d \z /smx;
+			return $character =~ m/ \A [0-9] \z /smx;
 		    }
 
 		    # Since we do not know what is in an interpolation, we
@@ -348,7 +350,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -356,7 +358,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
