@@ -38,8 +38,9 @@ use warnings;
 use base qw{ PPIx::Regexp::Token };
 
 use Carp qw{ confess };
+use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.055';
+our $VERSION = '0.069';
 
 sub __new {
     my ( $class, $content, %arg ) = @_;
@@ -52,6 +53,10 @@ sub __new {
 
     $self->{error} = $arg{error};
 
+    $self->{explanation} = defined $arg{explanation} ?
+	$arg{explanation} :
+	$arg{error};
+
     return $self;
 }
 
@@ -59,6 +64,11 @@ sub __new {
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
 
+sub explain {
+    my ( $self ) = @_;
+    return $self->{explanation};
+}
+
 =head2 ordinal
 
 This method returns the results of the ord built-in on the content
@@ -81,6 +91,9 @@ sub __PPIX_ELEM__rebless {
 	$self->{error} = 'Unspecified error';
 	$rslt++;
     }
+    $self->{explanation} = defined $arg{explanation} ?
+	$arg{explanation} :
+	$arg{error};
     return $rslt;
 }
 
@@ -98,7 +111,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -106,7 +119,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
