@@ -7,9 +7,14 @@ use base qw{ PPIx::Regexp::Support };
 
 use Carp qw{ carp croak confess };
 use PPIx::Regexp::Constant qw{
+    ARRAY_REF
+    CODE_REF
+    HASH_REF
     MINIMUM_PERL
+    REGEXP_REF
     TOKEN_LITERAL
     TOKEN_UNKNOWN
+    @CARP_NOT
 };
 use PPIx::Regexp::Token::Assertion		();
 use PPIx::Regexp::Token::Backreference		();
@@ -24,6 +29,7 @@ use PPIx::Regexp::Token::Control		();
 use PPIx::Regexp::Token::Delimiter		();
 use PPIx::Regexp::Token::Greediness		();
 use PPIx::Regexp::Token::GroupType::Assertion	();
+use PPIx::Regexp::Token::GroupType::Atomic_Script_Run	();
 use PPIx::Regexp::Token::GroupType::BranchReset	();
 use PPIx::Regexp::Token::GroupType::Code	();
 use PPIx::Regexp::Token::GroupType::Modifier	();
@@ -40,10 +46,10 @@ use PPIx::Regexp::Token::Recursion		();
 use PPIx::Regexp::Token::Structure		();
 use PPIx::Regexp::Token::Unknown		();
 use PPIx::Regexp::Token::Whitespace		();
-use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
+use PPIx::Regexp::Util qw{ is_ppi_regexp_element __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.055';
+our $VERSION = '0.069';
 
 our $DEFAULT_POSTDEREF;
 defined $DEFAULT_POSTDEREF
@@ -110,7 +116,7 @@ defined $DEFAULT_POSTDEREF
 	$errstr = undef;
 
 	exists $args{default_modifiers}
-	    and 'ARRAY' ne ref $args{default_modifiers}
+	    and ARRAY_REF ne ref $args{default_modifiers}
 	    and do {
 		$errstr = 'default_modifiers must be an array reference';
 		return;
@@ -151,10 +157,7 @@ defined $DEFAULT_POSTDEREF
 	};
 
 	if ( __instance( $re, 'PPI::Element' ) ) {
-	    defined( my $tokenizer_class = __choose_tokenizer_class(
-		    $re, { parse => 'guess' } ) )
-		or return __set_errstr( ref $re, 'not supported' );
-	    $class eq $tokenizer_class
+	    is_ppi_regexp_element( $re )
 		or return __set_errstr( ref $re, 'not supported by', $class );
 	    # TODO conditionalizstion on PPI class does not really
 	    # belong here, but at the moment I have no other idea of
@@ -210,7 +213,7 @@ sub cookie {
 	or confess "Programming error - undefined cookie name";
     @args or return $self->{cookie}{$name};
     my $cookie = shift @args;
-    if ( ref $cookie eq 'CODE' ) {
+    if ( CODE_REF eq ref $cookie ) {
 	return ( $self->{cookie}{$name} = $cookie );
     } elsif ( defined $cookie ) {
 	confess "Programming error - cookie must be CODE ref or undef";
@@ -226,7 +229,7 @@ sub default_modifiers {
 
 sub __effective_modifiers {
     my ( $self ) = @_;
-    'HASH' eq ref $self->{effective_modifiers}
+    HASH_REF eq ref $self->{effective_modifiers}
 	or return {};
     return { %{ $self->{effective_modifiers} } };
 }
@@ -306,7 +309,7 @@ sub find_matching_delimiter {
 sub find_regexp {
     my ( $self, $regexp ) = @_;
 
-    ref $regexp eq 'Regexp'
+    REGEXP_REF eq ref $regexp
 	or confess
 	'Argument is a ', ( ref $regexp || 'scalar' ), ' not a Regexp';
 
@@ -472,6 +475,15 @@ sub modifier_pop {
     return;
 }
 
+sub modifier_seen {
+    my ( $self, $modifier ) = @_;
+    foreach my $mod ( reverse @{ $self->{modifiers} } ) {
+	exists $mod->{$modifier}
+	    and return 1;
+    }
+    return;
+}
+
 sub next_token {
     my ( $self ) = @_;
 
@@ -518,19 +530,6 @@ sub ppi_document {
     return PPI::Document->new( \"$self->{find}" );
 }
 
-sub prior {
-    my ( $self, $method, @args ) = @_;
-    $self->_deprecation_notice( method => 'prior',
-	'prior_significant_token()' );
-    defined $method or return $self->{prior_significant_token};
-    $self->{prior_significant_token}->can( $method )
-	or confess 'Programming error - ',
-	    ( ref $self->{prior_significant_token} ||
-		$self->{prior_significant_token} ),
-	    ' does not support method ', $method;
-    return $self->{prior_significant_token}->$method( @args );
-}
-
 sub prior_significant_token {
     my ( $self, $method, @args ) = @_;
     defined $method or return $self->{prior_significant_token};
@@ -591,7 +590,7 @@ sub prior_significant_token {
 	    $iterator = sub {
 		return shift @eles;
 	    };
-	} elsif ( 'CODE' ne ref $iterator ) {
+	} elsif ( CODE_REF ne ref $iterator ) {
 	    confess 'Programming error - Iterator not understood';
 	}
 
@@ -733,6 +732,8 @@ sub tokens {
 #	This method returns true if the deprecation is in progress. In
 #	fact it returns the deprecation level.
 
+=begin comment
+
 {
 
     my %deprecate = (
@@ -760,20 +761,18 @@ sub tokens {
 	return;
     }
 
-=begin comment
-
     sub _deprecation_in_progress {
 	my ( $self, $type, $name ) = @_;
 	$deprecate{$type} or return;
 	return $deprecate{$type}{$name};
     }
 
+}
+
 =end comment
 
 =cut
 
-}
-
 sub _remainder {
     my ( $self ) = @_;
 
@@ -822,14 +821,22 @@ sub __PPIX_TOKENIZER__init {
     my ( $self ) = @_;
 
     $self->find_regexp(
-	qr{ \A ( \s* ) ( qr | m | s )? ( \s* ) (?: [^\w\s] ) }smx )
+	qr{ \A ( \s* ) ( qr | m | s )? ( \s* ) ( . ) }smx )
 	or return $self->__init_error();
 
-    my ( $leading_white, $type, $next_white ) = $self->capture();
+    my ( $leading_white, $type, $next_white, $delim_start ) = $self->capture();
 
     defined $type
 	or $type = '';
 
+    $type
+	or $delim_start =~ m< \A [/?] \z >smx
+	or return $self->__init_error();
+    $type
+	and not $next_white
+	and $delim_start =~ m< \A \w \z >smx
+	and return $self->__init_error();
+
     $self->{type} = $type;
 
     my @tokens;
@@ -843,13 +850,10 @@ sub __PPIX_TOKENIZER__init {
 	and push @tokens, $self->make_token( length $next_white,
 	'PPIx::Regexp::Token::Whitespace' );
 
-    $self->{delimiter_start} = substr
-	$self->{content},
-	$self->{cursor_curr},
-	1;
+    $self->{delimiter_start} = $delim_start;
 
     $self->{trace}
-	and warn "Tokenizer found regexp start delimiter '$self->{delimiter_start}' at $self->{cursor_curr}\n";
+	and warn "Tokenizer found regexp start delimiter '$delim_start' at $self->{cursor_curr}\n";
 
     if ( my $offset = $self->find_matching_delimiter() ) {
 	my $cursor_limit = $self->{cursor_curr} + $offset;
@@ -1319,6 +1323,9 @@ appears. In this case an exception will be thrown if you specify a
 multi-character modifier (e.g.  C<'ee*'>), or if you specify one of the
 match semantics modifiers (e.g.  C<'a*'>).
 
+If called by an external tokenizer, this method returns true if if the
+given modifier was true at the current point in the tokenization.
+
 =head2 next_token
 
  my $token = $tokenizer->next_token();
@@ -1416,8 +1423,8 @@ can be abbreviated by removing the leading 'PPIx::Regexp::'.
 If no class is specified, this method does nothing.
 
 The expectation lasts from the next time L</get_token> is called until
-the next time L<make_token> makes a significant token, or until the next
-C<expect> call if that is done sooner.
+the next time L</make_token> makes a significant token, or until the
+next C<expect> call if that is done sooner.
 
 =head2 find_regexp
 
@@ -1553,6 +1560,17 @@ whose content is ')'.
 Note that this method will never pop the last modifier item off the
 stack, to guard against unmatched right parentheses.
 
+=head2 modifier_seen
+
+ $tokenizer->modifier_seen( 'i' )
+     and print "/i was seen at some point.\n";
+
+Unlike L<modifier()|/modifier>, this method returns a true value if the
+given modifier has been seen in any scope visible from the current
+location in the parse. There is no magic for group match semantics (
+/a, /aa, /d, /l, /u) or modifiers that can be repeated, like /x and /xx,
+or /e and /ee.
+
 =head2 peek
 
  my $character = $tokenizer->peek();
@@ -1569,29 +1587,6 @@ C<undef> is returned.
 This method makes a PPI document out of the remainder of the string, and
 returns it.
 
-=head2 prior
-
- $tokenizer->prior( 'can_be_quantified' )
-    and print "The prior token can be quantified.\n";
-
-This method is deprecated in favor of
-L<prior_significant_tokrn()|/prior_significant_token>. As of version [%%
-next_version %%] it is a fatal error to call it. Six months after the
-release of this version it will be removed.  I am not sure I need to put
-this though a deprecation cycle, given that this method is documented as
-not being part of the public interface, but I choose to err on the side
-of caution.
-
-This method calls the named method on the most-recently-instantiated
-significant token, and returns the result. Any arguments subsequent to
-the method name will be passed to the method.
-
-Because this method is designed to be used within the tokenizing system,
-it will die horribly if the named method does not exist.
-
-If called with no arguments at all the most-recently-instantiated
-significant token is returned.
-
 =head2 prior_significant_token
 
  $tokenizer->prior_significant_token( 'can_be_quantified' )
@@ -1628,7 +1623,7 @@ troubleshoot funny output from the tokenizer.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -1636,7 +1631,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
